aboutsummaryrefslogtreecommitdiffstats
path: root/tests/unit/Access/PermissionLimitsTest.php
diff options
context:
space:
mode:
Diffstat (limited to 'tests/unit/Access/PermissionLimitsTest.php')
-rw-r--r--tests/unit/Access/PermissionLimitsTest.php7
1 files changed, 3 insertions, 4 deletions
diff --git a/tests/unit/Access/PermissionLimitsTest.php b/tests/unit/Access/PermissionLimitsTest.php
index 57ad42a19..0a90d11df 100644
--- a/tests/unit/Access/PermissionLimitsTest.php
+++ b/tests/unit/Access/PermissionLimitsTest.php
@@ -45,8 +45,8 @@ class PermissionLimitsTest extends UnitTestCase {
* @uses ::call_hooks
*/
public function testStd_Limits() {
- // There are 18 default perms
- $permsCount = 18;
+ // There are 17 default perms
+ $permsCount = 17;
// Create a stub for global function t() with expectation
$t = $this->getFunctionMock('Zotlabs\Access', 't');
@@ -69,10 +69,9 @@ class PermissionLimitsTest extends UnitTestCase {
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['post_comments']);
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['post_mail']);
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['post_like']);
- $this->assertEquals(PERMS_SPECIFIC, $stdlimits['tag_deliver']);
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['chat']);
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['republish']);
$this->assertEquals(PERMS_SPECIFIC, $stdlimits['delegate']);
}
-} \ No newline at end of file
+}